==> 29wptouch-2.8.12.zip: wptouch/themes/29/header.php <==
<?php include( dirname(__FILE__) . '/../core29/core-header.php' ); 
// End WPtouch Core Header
?>
<body class="<?php wptouch_core_body_background(); ?> <?php wptouch_idevice_classes(); ?>">
<!-- New noscript check, we need js on now folks -->
<noscript>
<div id="noscript-wrap">
	<div id="noscript">
		<h2><?php _e("Notice", "wptouch"); ?></h2>
		<p><?php _e("JavaScript for Mobile Safari is currently turned off.", "wptouch"); ?></p>
		<p><?php _e("Turn it on in ", "wptouch"); ?><em><?php _e("Settings &rsaquo; Safari", "wptouch"); ?></em><br /><?php _e(" to view this website.", "wptouch"); ?></p>
	</div>
</div>
</noscript>
 <!-- #start The Search Overlay -->
	<div id="wptouch-search"> 
 		<div id="wptouch-search-inner">
<!-- ▼検索Adsense▼ -->

<!-- ▲検索Adsense▲ -->

		</div>
	</div>



<div id="headerbar">
	<div id="headerbar-title">
		<!-- This fetches the admin selection logo icon for the header, which is also the bookmark icon -->
		<a href="<?php echo home_url('/'); ?>"><?php wptouch_core_body_sitetitle(); ?></a>
<div id="headerbar-menu">
		    <a id="searchopen" class="top" href="javascript:return false;">検索</a>
	</div>
	</div>
</div>

 <!-- #start Menu Area -->
   <ul id="menu" class="clearfix">
   <li class="menuH"><a href="<?php bloginfo('url'); ?>">ホーム</a></li>
   <li class="menuE"><span>コメント</span></li>
   <li class="menuC"><span>カテゴリー</span></li>
   <li class="menuA"><span>過去記事</span></li>
   <li class="menuP"><span>Special</span></li>
  </ul>


  <div id="select-menu">

<ul id="menuE" style="display:none;">
<?php
$comments = get_comments('type=comment&status=approve&number=10');
$output = '';
if(is_array($comments) && count($comments) == 0) echo "コメントはありません。";
//コメントがある場合
else{
	//コメントを記事ごとにまとめる
	foreach($comments as $comment){
		isset($posts_list[$comment->comment_post_ID])? $posts_list[$comment->comment_post_ID]++ : $posts_list[$comment->comment_post_ID] = 1;
	}
	while(list($key, $val) = each($posts_list)){
		$first_comment = true;
		foreach($comments as $comment){
			$author = "匿名";
			if($comment->comment_post_ID != $key) continue;
			if($first_comment){
				//記事タイトル取得
				$comment_post = get_post($comment->comment_post_ID);
				$post_title = mb_strimwidth($comment_post->post_title, 0, 40, "...", "UTF-8");
				$permalink = get_permalink($comment->comment_post_ID)."#comments";
				$output .= "<li><a href=\"$permalink\">$post_title</a>\n";
				$output .= "\t<ul>\n";
				$first_comment = false;
			}
			$commentid = get_permalink($comment->comment_post_ID)."#comment-".$comment->comment_ID;
			if(mysql2date('Ymd', $comment->comment_date)== date_i18n('Ymd')) $comment_date = mysql2date('H:i', $comment->comment_date);
			elseif(mysql2date('Y', $comment->comment_date)== date_i18n('Y')) $comment_date = mysql2date('m/d', $comment->comment_date);
			else $comment_date = mysql2date('Y/m/d', $comment->comment_date);
			if($comment->comment_author) $author = mb_strimwidth($comment->comment_author, 0, 30, "...", "UTF-8");
			$output .= "\t\t<li><span class=\"comment_author\"><a href=\"$commentid\" title=\"\">".$author."</a> </span>".
			"<span class=\"comment_date\">( $comment_date )</span></li>\n";
		}
		$output .= "\t</ul>\n</li>\n";
	}
	echo $output;
} ?>

</ul>

   <ul id="menuA" style="display:none;">
    <?php wp_get_archives('type=monthly&limit=12'); ?></ul>

<ul id="menuC" style="display:none;">
<?php
wp_list_categories('title_li='); ?>
<!--/category--></ul>
   <ul id="menuA" style="display:none;">
    <?php wp_get_archives('type=monthly'); ?></ul>
   <ul id="menuP" style="display:none;">
<li><a href="http://29college.biz/">29college</a></li>
<li><a href="http://29mailmaga.com/">稼ぐ力を学ぶ無料講座</a></li>
</ul>
</div>

<div class="ad_footer">
----------sponsored link----------<br />
<!-- ▼Adsense:最上部▼ -->

<!-- ▲Adsense:最上部▲ -->
</div>

<?php wptouch_core_header_check_use();

==> 29wptouch2.9.8.zip: wptouch/themes/29/header.php <==
<?php include( dirname(__FILE__) . '/../core29/core-header.php' ); 
// End WPtouch Core Header
?>
<body class="<?php wptouch_core_body_background(); ?> <?php wptouch_idevice_classes(); ?>">
<!-- New noscript check, we need js on now folks -->
<noscript>
<div id="noscript-wrap">
	<div id="noscript">
		<h2><?php _e("Notice", "wptouch"); ?></h2>
		<p><?php _e("JavaScript for Mobile Safari is currently turned off.", "wptouch"); ?></p>
		<p><?php _e("Turn it on in ", "wptouch"); ?><em><?php _e("Settings &rsaquo; Safari", "wptouch"); ?></em><br /><?php _e(" to view this website.", "wptouch"); ?></p>
	</div>
</div>
</noscript>
<div id="headerbar">
	<div id="headerbar-title">
		<h1><a href="<?php echo home_url('/'); ?>">
<!-- ▼サイトタイトル部分（バナーにする場合はここを画像に変更）▼ -->
<?php wptouch_core_body_sitetitle(); ?><div class="s5"></div>
<!-- ▲サイトタイトル部分▲ -->
</a></h1>
	</div>
</div>

<!-- ▼メニュー▼ -->
   <ul id="menu" class="clearfix">
   <li class="menuH"><a href="<?php bloginfo('url'); ?>">ホーム</a></li>
   <li class="menuE"><span>コメント</span></li>
   <li class="menuC"><span>カテゴリー</span></li>
   <li class="menuA"><span>過去記事</span></li>
   <li class="menuP"><span>リンク</span></li>
  </ul>

<div id="select-menu">
<!-- ▼左から二番目のメニューの中身▼ -->
<ul id="menuE" style="display:none;">
<?php
$comments = get_comments('type=comment&status=approve&number=10');
$output = '';
if(is_array($comments) && count($comments) == 0) echo "コメントはありません。";
//コメントがある場合
else{
	//コメントを記事ごとにまとめる
	foreach($comments as $comment){
		isset($posts_list[$comment->comment_post_ID])? $posts_list[$comment->comment_post_ID]++ : $posts_list[$comment->comment_post_ID] = 1;
	}
	while(list($key, $val) = each($posts_list)){
		$first_comment = true;
		foreach($comments as $comment){
			$author = "匿名";
			if($comment->comment_post_ID != $key) continue;
			if($first_comment){
				//記事タイトル取得
				$comment_post = get_post($comment->comment_post_ID);
				$post_title = mb_strimwidth($comment_post->post_title, 0, 40, "...", "UTF-8");
				$permalink = get_permalink($comment->comment_post_ID)."#comments";
				$output .= "<li><a href=\"$permalink\">$post_title</a>\n";
				$output .= "\t<ul>\n";
				$first_comment = false;
			}
			$commentid = get_permalink($comment->comment_post_ID)."#comment-".$comment->comment_ID;
			if(mysql2date('Ymd', $comment->comment_date)== date_i18n('Ymd')) $comment_date = mysql2date('H:i', $comment->comment_date);
			elseif(mysql2date('Y', $comment->comment_date)== date_i18n('Y')) $comment_date = mysql2date('m/d', $comment->comment_date);
			else $comment_date = mysql2date('Y/m/d', $comment->comment_date);
			if($comment->comment_author) $author = mb_strimwidth($comment->comment_author, 0, 30, "...", "UTF-8");
			$output .= "\t\t<li><span class=\"comment_author\"><a href=\"$commentid\" title=\"\">".$author."</a> </span>".
			"<span class=\"comment_date\">( $comment_date )</span></li>\n";
		}
		$output .= "\t</ul>\n</li>\n";
	}
	echo $output;
} ?>

</ul>

<!-- ▼左から三番目のメニューの中身▼ -->
<ul id="menuC" style="display:none;">
<?php
wp_list_categories('title_li='); ?>
</ul>

<!-- ▼左から四番目のメニューの中身▼ -->
<ul id="menuA" style="display:none;">
<?php wp_get_archives('type=monthly&limit=12'); ?></ul>

<!-- ▼一番右のメニューの中身▼ -->
<ul id="menuP" style="display:none;">
<li><a href="http://29college.biz/">29college</a></li>
<li><a href="http://29mailmaga.com/">稼ぐ力を学ぶ無料講座</a></li>
</ul>
</div>


<div class="hsearch">
<form role="search" method="get" id="searchform" class="searchform" action="<?php echo esc_url( home_url( '/' ) ); ?>">
	<div>
		<label class="screen-reader-text" for="s"><?php _x( 'Search for:', 'label' ); ?></label>
		<input type="text" value="<?php echo get_search_query(); ?>" name="s" id="s" />
		<input type="submit" id="searchsubmit" value="　　" />
	</div>
</form>
</div>

<div class="ad_footer">
----------sponsored link----------<br />
<!-- ▼Adsense:最上部▼ -->

<!-- ▲Adsense:最上部▲ -->
</div>

<?php wptouch_core_header_check_use();
